@@ -27,7 +27,7 @@
 
 #include <KLocalizedString>
 
-#include <qbuffer.h>
+#include <QBuffer>
 
 #include <stdio.h>
 #include <assert.h>
@@ -39,7 +39,7 @@ class KPlayerPrivate
 public:
    KPlayerPrivate()
    {
-      mNetworkPlayer = 0;
+      mNetworkPlayer = nullptr;
    }
 
    KGame *mGame;
@@ -81,7 +81,7 @@ void KPlayer::init()
                                        SLOT(emitSignal(KGamePropertyBase*)));
    d->mVirtual=false;
    d->mActive=true;
-   d->mGame=0;
+   d->mGame=nullptr;
    d->mId=0; // "0" is always an invalid ID!
    d->mPriority=0;
    // I guess we cannot translate the group otherwise no
@@ -301,7 +301,7 @@ bool KPlayer::removeGameIO(KGameIO *targetinput,bool deleteit)
     }
     else
     {
-      targetinput->setPlayer(0);
+      targetinput->setPlayer(nullptr);
       result = d->mInputList.removeAll(targetinput);
     }
   }
@@ -310,7 +310,7 @@ bool KPlayer::removeGameIO(KGameIO *targetinput,bool deleteit)
 
 bool KPlayer::hasRtti(int rtti) const
 {
-  return findRttiIO(rtti) != 0;
+  return findRttiIO(rtti) != nullptr;
 }
 
 KGameIO * KPlayer::findRttiIO(int rtti) const
@@ -324,7 +324,7 @@ KGameIO * KPlayer::findRttiIO(int rtti) const
       return curGameIO;
     }
   }
-  return 0;
+  return nullptr;
 }
 
 int KPlayer::calcIOValue()
@@ -388,7 +388,7 @@ bool KPlayer::load(QDataStream &stream)
       qCCritical(GAMES_PRIVATE_KGAME) << "   Player loading error. probably format error";
   }
 
-  // emit signalLoad(stream);
+  // Q_EMIT signalLoad(stream);
   return true;
 }
 
@@ -400,7 +400,7 @@ bool KPlayer::save(QDataStream &stream)
 
   stream << (qint16)KPLAYER_LOAD_COOKIE;
 
-  //emit signalSave(stream);
+  //Q_EMIT signalSave(stream);
   return true;
 }
 
@@ -432,7 +432,7 @@ void KPlayer::networkTransmission(QDataStream &stream,int msgid,quint32 sender)
       }
     break;
     default:
-        emit signalNetworkData(msgid - KGameMessage::IdUser,
+        Q_EMIT signalNetworkData(msgid - KGameMessage::IdUser,
 	        ((QBuffer*)stream.device())->readAll(),sender,this);
         qCDebug(GAMES_PRIVATE_KGAME) << ": "
 	        << "User data msgid" << msgid;
@@ -475,7 +475,7 @@ void KPlayer::emitSignal(KGamePropertyBase *me)
       it.next()->notifyTurn(d->mMyTurn.value());
     }
   }
-  emit signalPropertyChanged(me,this);
+  Q_EMIT signalPropertyChanged(me,this);
 }
 
 // --------------------- DEBUG --------------------
